pub trait RequestBuilder {
type Client: Client;
// Required method
fn build_split(self) -> (Self::Client, Result<Request, Error>);
}Expand description
A generic request builder.
This is needed by Upgraded to be generic over the specific implementation of a request (and client).
Its only requirements are that it provides the specific client type, and can build itself into a client and a reqwest::Request.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl RequestBuilder for RequestBuilder
Available on crate feature middleware only.
impl RequestBuilder for RequestBuilder
Available on crate feature
middleware only.